@@ -19,7 +19,10 @@ import mock
 
 import sushy
 from sushy import exceptions
+from sushy.resources.chassis import chassis
 from sushy.resources import constants as res_cons
+from sushy.resources.manager import manager
+from sushy.resources.oem import fake
 from sushy.resources.system import bios
 from sushy.resources.system import mappings as sys_map
 from sushy.resources.system import processor
@@ -67,6 +70,8 @@ class SystemTestCase(base.TestCase):
                          self.sys_inst.power_state)
         self.assertEqual(96, self.sys_inst.memory_summary.size_gib)
         self.assertEqual("OK", self.sys_inst.memory_summary.health)
+        for oem_vendor in self.sys_inst.oem_vendors:
+            self.assertIn(oem_vendor, ('Contoso', 'Chipwise'))
 
     def test__parse_attributes_missing_actions(self):
         self.sys_inst.json.pop('Actions')
@@ -478,6 +483,39 @@ class SystemTestCase(base.TestCase):
         # | WHEN & THEN |
         self.assertIsInstance(self.sys_inst.storage, storage.StorageCollection)
 
+    def test_managers(self):
+        # | GIVEN |
+        with open('sushy/tests/unit/json_samples/'
+                  'manager.json') as f:
+            self.conn.get.return_value.json.return_value = json.load(f)
+
+        # | WHEN & THEN |
+        actual_managers = self.sys_inst.managers
+        self.assertIsInstance(actual_managers[0], manager.Manager)
+        self.assertEqual(
+            '/redfish/v1/Managers/BMC', actual_managers[0].path)
+
+    def test_chassis(self):
+        # | GIVEN |
+        with open('sushy/tests/unit/json_samples/'
+                  'chassis.json') as f:
+            self.conn.get.return_value.json.return_value = json.load(f)
+
+        # | WHEN & THEN |
+        actual_chassis = self.sys_inst.chassis
+        self.assertIsInstance(actual_chassis[0], chassis.Chassis)
+        self.assertEqual(
+            '/redfish/v1/Chassis/1U', actual_chassis[0].path)
+
+    def test_get_oem_extension(self):
+        # | WHEN |
+        contoso_system_extn_inst = self.sys_inst.get_oem_extension('Contoso')
+        # | THEN |
+        self.assertIsInstance(contoso_system_extn_inst,
+                              fake.FakeOEMSystemExtension)
+        self.assertIs(self.sys_inst, contoso_system_extn_inst.core_resource)
+        self.assertEqual('Contoso', contoso_system_extn_inst.oem_property_name)
+
 
 class SystemCollectionTestCase(base.TestCase):
 
